==> auto-ui-2.4.55.tgz: package/es/card/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import LazyImg from '../lazy-img';
import './style/index.scss';
var CardFigure = function (props) {
    var image = props.image, title = props.title, children = props.children, onClick = props.onClick, className = props.className, aspectRatio = props.aspectRatio, otherProps = __rest(props, ["image", "title", "children", "onClick", "className", "aspectRatio"]);
    var cls = cn('x-card__figure', {
        'x-card__figure--activable': !!onClick,
        'x-card__figure--ar': aspectRatio && aspectRatio > 0,
    }, className);
    var arstyle = {};
    if (aspectRatio && aspectRatio > 0) {
        arstyle.marginTop = (1 / aspectRatio) * 100 + "%";
    }
    return (React.createElement("figure", __assign({}, otherProps, { className: cls, onClick: onClick }),
        children && React.createElement("div", { className: "x-card__figure-content" }, children),
        React.createElement(LazyImg, { className: aspectRatio && aspectRatio > 0 ? 'x-card__figure-abs-img' : '', src: image, alt: title, title: title }),
        aspectRatio && aspectRatio > 0 ? React.createElement("div", { className: "x-card__ar", style: arstyle }) : null));
};
var Card = function (props) {
    var shadow = props.shadow, children = props.children, direction = props.direction, aspectRatio = props.aspectRatio, onClick = props.onClick, className = props.className, otherProps = __rest(props, ["shadow", "children", "direction", "aspectRatio", "onClick", "className"]);
    var cls = cn('x-card', {
        'x-card--shadow': shadow,
        'x-card--ar': aspectRatio && aspectRatio > 0,
        'x-card--activable': !!onClick,
    }, className);
    var arstyle = {};
    if (aspectRatio && aspectRatio > 0) {
        arstyle.marginTop = (1 / aspectRatio) * 100 + "%";
    }
    return (React.createElement("div", __assign({}, otherProps, { className: cls, onClick: onClick }),
        React.createElement("div", { className: "x-card__inner x-card--" + (direction || 'column') }, children),
        aspectRatio && aspectRatio > 0 ? React.createElement("div", { className: "x-card__ar", style: arstyle }) : null));
};
Card.Figure = CardFigure;
export default Card;

==> auto-ui-2.4.63.tgz: package/es/card/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import LazyImg from '../lazy-img';
import './style/index.scss';
var CardFigure = function (props) {
    var image = props.image, title = props.title, children = props.children, onClick = props.onClick, className = props.className, aspectRatio = props.aspectRatio, otherProps = __rest(props, ["image", "title", "children", "onClick", "className", "aspectRatio"]);
    var cls = cn('x-card__figure', {
        'x-card__figure--activable': !!onClick,
        'x-card__figure--ar': aspectRatio && aspectRatio > 0,
    }, className);
    var arstyle = {};
    if (aspectRatio && aspectRatio > 0) {
        arstyle.marginTop = (1 / aspectRatio) * 100 + "%";
    }
    return (React.createElement("figure", __assign({}, otherProps, { className: cls, onClick: onClick }),
        children && React.createElement("div", { className: "x-card__figure-content" }, children),
        React.createElement(LazyImg, { className: aspectRatio && aspectRatio > 0 ? 'x-card__figure-abs-img' : '', src: image, alt: title, title: title }),
        aspectRatio && aspectRatio > 0 ? React.createElement("div", { className: "x-card__ar", style: arstyle }) : null));
};
var Card = function (props) {
    var shadow = props.shadow, children = props.children, direction = props.direction, aspectRatio = props.aspectRatio, onClick = props.onClick, className = props.className, otherProps = __rest(props, ["shadow", "children", "direction", "aspectRatio", "onClick", "className"]);
    var cls = cn('x-card', {
        'x-card--shadow': shadow,
        'x-card--ar': aspectRatio && aspectRatio > 0,
        'x-card--activable': !!onClick,
    }, className);
    var arstyle = {};
    if (aspectRatio && aspectRatio > 0) {
        arstyle.marginTop = (1 / aspectRatio) * 100 + "%";
    }
    return (React.createElement("div", __assign({}, otherProps, { className: cls, onClick: onClick }),
        React.createElement("div", { className: "x-card__inner x-card--" + (direction || 'column') }, children),
        aspectRatio && aspectRatio > 0 ? React.createElement("div", { className: "x-card__ar", style: arstyle }) : null));
};
Card.Figure = CardFigure;
export default Card;
